@@ -35,6 +35,23 @@ class GossAzureBlobClient(object):
             if not isinstance(err, ResourceExistsError):
                 return "", err
         return self._get_object_url(key), None
+    
+    def _upload_object_by_block(self, local_path, key):
+        """
+        Upload object to azure cloud by block
+        """
+        try:
+            blob_client = self._blob_client(self._bucket, key)
+            with open(local_path, "rb") as data:
+                self._delete_object(key)
+                if self._region:
+                    blob_client.upload_blob(data, blob_type="AppendBlob", content_settings=ContentSettings(content_type=self._region))
+                else:
+                    blob_client.upload_blob(data, blob_type="AppendBlob")
+        except Exception as err:
+            if not isinstance(err, ResourceExistsError):
+                return "", err
+        return self._get_object_url(key), None
 
     def _list_objects(self, prefix):
         """
